@@ -3,7 +3,7 @@ use std::cmp::Ordering;
 #[cfg(not(feature = "library"))]
 use cosmwasm_std::entry_point;
 use cosmwasm_std::{
-    attr, to_binary, Binary, BlockInfo, CosmosMsg, Deps, DepsMut, Empty, Env, MessageInfo, Order,
+    to_binary, Binary, BlockInfo, CosmosMsg, Deps, DepsMut, Empty, Env, MessageInfo, Order,
     Response, StdResult,
 };
 
@@ -134,17 +134,11 @@ pub fn execute_propose(
     };
     BALLOTS.save(deps.storage, (id.into(), &info.sender), &ballot)?;
 
-    Ok(Response {
-        submessages: vec![],
-        messages: vec![],
-        attributes: vec![
-            attr("action", "propose"),
-            attr("sender", info.sender),
-            attr("proposal_id", id),
-            attr("status", format!("{:?}", prop.status)),
-        ],
-        data: None,
-    })
+    Ok(Response::new()
+        .add_attribute("action", "propose")
+        .add_attribute("sender", info.sender)
+        .add_attribute("proposal_id", id.to_string())
+        .add_attribute("status", format!("{:?}", prop.status)))
 }
 
 pub fn execute_vote(
@@ -191,17 +185,11 @@ pub fn execute_vote(
         PROPOSALS.save(deps.storage, proposal_id.into(), &prop)?;
     }
 
-    Ok(Response {
-        submessages: vec![],
-        messages: vec![],
-        attributes: vec![
-            attr("action", "vote"),
-            attr("sender", info.sender),
-            attr("proposal_id", proposal_id),
-            attr("status", format!("{:?}", prop.status)),
-        ],
-        data: None,
-    })
+    Ok(Response::new()
+        .add_attribute("action", "vote")
+        .add_attribute("sender", info.sender)
+        .add_attribute("proposal_id", proposal_id.to_string())
+        .add_attribute("status", format!("{:?}", prop.status)))
 }
 
 pub fn execute_execute(
@@ -224,16 +212,11 @@ pub fn execute_execute(
     PROPOSALS.save(deps.storage, proposal_id.into(), &prop)?;
 
     // dispatch all proposed messages
-    Ok(Response {
-        submessages: vec![],
-        messages: prop.msgs,
-        attributes: vec![
-            attr("action", "execute"),
-            attr("sender", info.sender),
-            attr("proposal_id", proposal_id),
-        ],
-        data: None,
-    })
+    Ok(Response::new()
+        .add_messages(prop.msgs)
+        .add_attribute("action", "execute")
+        .add_attribute("sender", info.sender)
+        .add_attribute("proposal_id", proposal_id.to_string()))
 }
 
 pub fn execute_close(
@@ -259,16 +242,10 @@ pub fn execute_close(
     prop.status = Status::Rejected;
     PROPOSALS.save(deps.storage, proposal_id.into(), &prop)?;
 
-    Ok(Response {
-        submessages: vec![],
-        messages: vec![],
-        attributes: vec![
-            attr("action", "close"),
-            attr("sender", info.sender),
-            attr("proposal_id", proposal_id),
-        ],
-        data: None,
-    })
+    Ok(Response::new()
+        .add_attribute("action", "close")
+        .add_attribute("sender", info.sender)
+        .add_attribute("proposal_id", proposal_id.to_string()))
 }
 
 #[cfg_attr(not(feature = "library"), entry_point)]
@@ -639,17 +616,11 @@ mod tests {
         // Verify
         assert_eq!(
             res,
-            Response {
-                submessages: vec![],
-                messages: vec![],
-                attributes: vec![
-                    attr("action", "propose"),
-                    attr("sender", VOTER3),
-                    attr("proposal_id", 1),
-                    attr("status", "Open"),
-                ],
-                data: None,
-            }
+            Response::new()
+                .add_attribute("action", "propose")
+                .add_attribute("sender", VOTER3)
+                .add_attribute("proposal_id", 1.to_string())
+                .add_attribute("status", "Open")
         );
 
         // Proposal from voter with enough vote power directly passes
@@ -659,17 +630,11 @@ mod tests {
         // Verify
         assert_eq!(
             res,
-            Response {
-                submessages: vec![],
-                messages: vec![],
-                attributes: vec![
-                    attr("action", "propose"),
-                    attr("sender", VOTER4),
-                    attr("proposal_id", 2),
-                    attr("status", "Passed"),
-                ],
-                data: None,
-            }
+            Response::new()
+                .add_attribute("action", "propose")
+                .add_attribute("sender", VOTER4)
+                .add_attribute("proposal_id", 2.to_string())
+                .add_attribute("status", "Passed")
         );
     }
 
@@ -720,17 +685,11 @@ mod tests {
         // Verify
         assert_eq!(
             res,
-            Response {
-                submessages: vec![],
-                messages: vec![],
-                attributes: vec![
-                    attr("action", "vote"),
-                    attr("sender", VOTER1),
-                    attr("proposal_id", proposal_id),
-                    attr("status", "Open"),
-                ],
-                data: None,
-            }
+            Response::new()
+                .add_attribute("action", "vote")
+                .add_attribute("sender", VOTER1)
+                .add_attribute("proposal_id", proposal_id.to_string())
+                .add_attribute("status", "Open")
         );
 
         // No/Veto votes have no effect on the tally
@@ -779,17 +738,11 @@ mod tests {
         // Verify
         assert_eq!(
             res,
-            Response {
-                submessages: vec![],
-                messages: vec![],
-                attributes: vec![
-                    attr("action", "vote"),
-                    attr("sender", VOTER4),
-                    attr("proposal_id", proposal_id),
-                    attr("status", "Passed"),
-                ],
-                data: None,
-            }
+            Response::new()
+                .add_attribute("action", "vote")
+                .add_attribute("sender", VOTER4)
+                .add_attribute("proposal_id", proposal_id.to_string())
+                .add_attribute("status", "Passed")
         );
 
         // non-Open proposals cannot be voted
@@ -841,17 +794,11 @@ mod tests {
         // Verify
         assert_eq!(
             res,
-            Response {
-                submessages: vec![],
-                messages: vec![],
-                attributes: vec![
-                    attr("action", "vote"),
-                    attr("sender", VOTER3),
-                    attr("proposal_id", proposal_id),
-                    attr("status", "Passed"),
-                ],
-                data: None,
-            }
+            Response::new()
+                .add_attribute("action", "vote")
+                .add_attribute("sender", VOTER3)
+                .add_attribute("proposal_id", proposal_id.to_string())
+                .add_attribute("status", "Passed")
         );
 
         // In passing: Try to close Passed fails
@@ -866,16 +813,11 @@ mod tests {
         // Verify
         assert_eq!(
             res,
-            Response {
-                submessages: vec![],
-                messages: msgs,
-                attributes: vec![
-                    attr("action", "execute"),
-                    attr("sender", SOMEBODY),
-                    attr("proposal_id", proposal_id),
-                ],
-                data: None,
-            }
+            Response::new()
+                .add_messages(msgs)
+                .add_attribute("action", "execute")
+                .add_attribute("sender", SOMEBODY)
+                .add_attribute("proposal_id", proposal_id.to_string())
         );
 
         // In passing: Try to close Executed fails
@@ -949,16 +891,10 @@ mod tests {
         // Verify
         assert_eq!(
             res,
-            Response {
-                submessages: vec![],
-                messages: vec![],
-                attributes: vec![
-                    attr("action", "close"),
-                    attr("sender", SOMEBODY),
-                    attr("proposal_id", proposal_id),
-                ],
-                data: None,
-            }
+            Response::new()
+                .add_attribute("action", "close")
+                .add_attribute("sender", SOMEBODY)
+                .add_attribute("proposal_id", proposal_id.to_string())
         );
 
         // Trying to close it again fails
